#
# spec file for package perl-Crypt-OpenSSL-RSA
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name Crypt-OpenSSL-RSA
Name:           perl-Crypt-OpenSSL-RSA
Version:        0.33
Release:        1.7
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        RSA encoding and decoding, using the openSSL libraries
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/T/TO/TODDR/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
Patch0:         Crypt-OpenSSL-RSA.patch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Crypt::OpenSSL::Guess) >= 0.11
BuildRequires:  perl(Crypt::OpenSSL::Random)
Requires:       perl(Crypt::OpenSSL::Random)
Recommends:     perl(Crypt::OpenSSL::Bignum)
%{perl_requires}
# MANUAL BEGIN
BuildRequires:  openssl-devel
# MANUAL END

%description
'Crypt::OpenSSL::RSA' provides the ability to RSA encrypt strings which are
somewhat shorter than the block size of a key. It also allows for
decryption, signatures and signature verification.

_NOTE_: Many of the methods in this package can croak, so use 'eval', or
Error.pm's try/catch mechanism to capture errors. Also, while some methods
from earlier versions of this package return true on success, this (never
documented) behavior is no longer the case.

%prep
%autosetup  -n %{cpan_name}-%{version} -p1

%build
perl Makefile.PL INSTALLDIRS=vendor OPTIMIZE="%{optflags}"
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changes README README.md
%license LICENSE

%changelog
* Sat Jul  9 2022 Tina Müller <timueller+perl@suse.de>
- updated to 0.33
  see /usr/share/doc/packages/perl-Crypt-OpenSSL-RSA/Changes
  0.33 July 7 2022
  - Update for windows github CI
  - Remove duplicit 'LICENSE' key
  - Remove EUMM Remove version check
  - #31 by removing reference to RSA_SSLV23_PADDING (removed from OpenSSL starting from v3.0.0)
  - support passphase protected private key load
  - fix 'unsupported encryption' error on old library versions
  - Clarify croak message for missing passphrase on older cyphers
  - More structs opaqued in LibreSSL 3.5
  - Use a macro for dealing with older SSL lacking macros
  - more CI fixups. Drop testing for 5.10 and 5.8. Something is broken upstream.
* Thu Oct  7 2021 Pedro Monreal <pmonreal@suse.com>
- updated to 0.32
  see /usr/share/doc/packages/perl-Crypt-OpenSSL-RSA/Changes
  0.32 Wed Sep 8 2021
  - Prefix internal bn2sv function so it doesn't collide with Net::SSLeay
  - Ensure that verify() leaves openssl error stack clean on failure
  - Fixed broken SEE ALSO links.
  - prevent outer $SIG{__DIE__} handler from being called during optional require.
  - omit done_testing since it does not work for older perl versions
  * Rebase Crypt-OpenSSL-RSA.patch
* Sun Oct  7 2018 Dirk Stoecker <opensuse@dstoecker.de>
- Fix autogenerated changes to build again
  * Drop openssl110.patch (upstream)
* Tue Sep 25 2018 Stephan Kulow <coolo@suse.com>
- updated to 0.31
  see /usr/share/doc/packages/perl-Crypt-OpenSSL-RSA/Changes
  0.31 Mon Sep 24 2018
  - Remove default of SHA256 for RSA keys. This has caused significant
    problems with downstream modules and it has always been possible to
    do $key->use_sha256_hash()
* Wed May  2 2018 coolo@suse.com
- updated to 0.30
  see /usr/share/doc/packages/perl-Crypt-OpenSSL-RSA/Changes
  0.30 Tue May 1 2018
  - Working windows library detection
  - Actively testing on appveyor for windows now.
  - work correctly on LibreSSL
  0.29_03  Mon Apr 16 2018
  - Add whirlpool hash support.
  - Crypt::OpenSSL::Random is now required at comnpile-time.
  - Use the new interface to RSA_generate_key if available
  - Add library paths to LIBS from Crypt::OpenSSL::Guess
  0.29_02  Sun Apr 15 2018
  - Add missing require of Config::OpenSSL::Guess
  0.29_01  Fri Apr 13 2018
  - Adapt to OpenSSL 1.1.0 (dur-randir)
  - Move issue tracker to github.
  - Modernization as in Crypt::OpenSSL::Random.
  - better MSWin32 hints, fixes MSVC libraries,
  - more meta tests,
  - prefer hash mode NID_sha256 over NID_sha1 for sign
* Mon Aug 21 2017 tchvatal@suse.com
- Sort with spec-cleaner
- Add patch openssl110.patch fixing compatibility with openssl-1.1.0
* Wed Nov 30 2011 coolo@suse.com
- fix license (bnc#733411)
* Tue Nov 29 2011 coolo@suse.com
- update to 0.28
  - RT 56454 - Win32 compatibility patch (kmx@cpan.org)
  - RT 65947 - Fix RSA.pm break with perl 5.14+
* Tue May 17 2011 coolo@opensuse.org
- fix use of autoloader
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Sun Apr  4 2010 chris@computersalat.de
- update to 0.26
  - Change subclassing test to generate a 512 bit key in order to work
    around an odd issue seen on some 64-bit redhat systems.
    (CPAN bug 45498)
- cleanup spec
  o sort TAGS
  o update Url
  o fixed deps
    added Crypt::OpenSSL::Random
  o updated description
  o added missing clean section
  o added missing doc
- added perl-macros
* Sun Jan 10 2010 jengelh@medozas.de
- enable parallel build
* Tue Nov  4 2008 ro@suse.de
- add openssl-devel to BuildRequires to fi build
* Tue Oct 28 2008 varkoly@suse.de
- Initial version of perl-Crypt-OpenSSL-RSA
